==> jc-1.4.0.tar.gz: polyglot/types/PackageContextResolver.h <==
// public class polyglot.types.PackageContextResolver

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 53da559c13f33509 polyglot_types_PackageContextResolver

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_types_PackageContextResolver_H_
#define _JC_polyglot_types_PackageContextResolver_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_types_Named$object;
struct _jc_polyglot_types_Package$object;
struct _jc_polyglot_types_Resolver$object;
struct _jc_polyglot_types_TypeSystem$object;

// Typedefs
typedef struct _jc_polyglot_types_PackageContextResolver$sub_refs	_jc_polyglot_types_PackageContextResolver$sub_refs;
typedef struct _jc_polyglot_types_PackageContextResolver$sub_nonrefs	_jc_polyglot_types_PackageContextResolver$sub_nonrefs;
typedef struct _jc_polyglot_types_PackageContextResolver$refs	_jc_polyglot_types_PackageContextResolver$refs;
typedef struct _jc_polyglot_types_PackageContextResolver$nonrefs	_jc_polyglot_types_PackageContextResolver$nonrefs;
typedef struct _jc_polyglot_types_PackageContextResolver$object	_jc_polyglot_types_PackageContextResolver$object;

typedef const struct _jc_polyglot_types_PackageContextResolver$vmethods	_jc_polyglot_types_PackageContextResolver$vmethods;
typedef const struct _jc_polyglot_types_PackageContextResolver$vtable	_jc_polyglot_types_PackageContextResolver$vtable;
typedef const struct _jc_polyglot_types_PackageContextResolver$vtype	_jc_polyglot_types_PackageContextResolver$vtype;

// Constructors
extern void _jc_polyglot_types_PackageContextResolver$method$_init$21eeebb255dc8b4d(_jc_env *, struct _jc_polyglot_types_PackageContextResolver$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_polyglot_types_PackageContextResolver$method$find$6acc62ea1c707b3c(_jc_env *, struct _jc_polyglot_types_PackageContextResolver$object *, struct _jc_java_lang_String$object *);
extern struct _jc_object *_jc_polyglot_types_PackageContextResolver$method$package__5f$2a2aa1010d61af28(_jc_env *, struct _jc_polyglot_types_PackageContextResolver$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_types_PackageContextResolver$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_types_PackageContextResolver$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_PackageContextResolver$method_info$find$6acc62ea1c707b3c;
extern _jc_method _jc_polyglot_types_PackageContextResolver$method_info$package__5f$2a2aa1010d61af28;
extern _jc_method _jc_polyglot_types_PackageContextResolver$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_types_PackageContextResolver$vmethods {
	struct _jc_object	*(*find$6acc62ea1c707b3c)(_jc_env *, struct _jc_polyglot_types_PackageContextResolver$object *, struct _jc_java_lang_String$object *);
	struct _jc_object	*(*package__5f$2a2aa1010d61af28)(_jc_env *, struct _jc_polyglot_types_PackageContextResolver$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_types_PackageContextResolver$object *);
};

// Vtable
struct _jc_polyglot_types_PackageContextResolver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_PackageContextResolver$vmethods	polyglot_types_PackageContextResolver;
};

// Vtype
struct _jc_polyglot_types_PackageContextResolver$vtype {
	_jc_type			type;
	_jc_polyglot_types_PackageContextResolver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_PackageContextResolver$sub_refs {
	struct _jc_object	*p;
	struct _jc_object	*ts;
	struct _jc_object	*cr;
};

// Reference instance fields (object)
struct _jc_polyglot_types_PackageContextResolver$refs {
    _jc_polyglot_types_PackageContextResolver$sub_refs	polyglot_types_PackageContextResolver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_PackageContextResolver$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_PackageContextResolver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_PackageContextResolver$sub_nonrefs	polyglot_types_PackageContextResolver;
};

// Object instance structure
struct _jc_polyglot_types_PackageContextResolver$object {
	_jc_polyglot_types_PackageContextResolver$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_PackageContextResolver$vtype	*vtype;
	_jc_polyglot_types_PackageContextResolver$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_PackageContextResolver$vtype _jc_polyglot_types_PackageContextResolver$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_PackageContextResolver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_PackageContextResolver$class_object;

#endif	/* _JC_polyglot_types_PackageContextResolver_H_ */

==> jc-1.4.6.tar.gz: polyglot/types/PackageContextResolver.h <==
// public class polyglot.types.PackageContextResolver

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 53da559c13f33509 polyglot_types_PackageContextResolver

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_types_PackageContextResolver_H_
#define _JC_polyglot_types_PackageContextResolver_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_types_Named$object;
struct _jc_polyglot_types_Package$object;
struct _jc_polyglot_types_Resolver$object;
struct _jc_polyglot_types_TypeSystem$object;

// Typedefs
typedef struct _jc_polyglot_types_PackageContextResolver$sub_refs	_jc_polyglot_types_PackageContextResolver$sub_refs;
typedef struct _jc_polyglot_types_PackageContextResolver$sub_nonrefs	_jc_polyglot_types_PackageContextResolver$sub_nonrefs;
typedef struct _jc_polyglot_types_PackageContextResolver$refs	_jc_polyglot_types_PackageContextResolver$refs;
typedef struct _jc_polyglot_types_PackageContextResolver$nonrefs	_jc_polyglot_types_PackageContextResolver$nonrefs;
typedef struct _jc_polyglot_types_PackageContextResolver$object	_jc_polyglot_types_PackageContextResolver$object;

typedef const struct _jc_polyglot_types_PackageContextResolver$vmethods	_jc_polyglot_types_PackageContextResolver$vmethods;
typedef const struct _jc_polyglot_types_PackageContextResolver$vtable	_jc_polyglot_types_PackageContextResolver$vtable;
typedef const struct _jc_polyglot_types_PackageContextResolver$vtype	_jc_polyglot_types_PackageContextResolver$vtype;

// Constructors
extern void _jc_polyglot_types_PackageContextResolver$method$_init$21eeebb255dc8b4d(_jc_env *, struct _jc_polyglot_types_PackageContextResolver$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_polyglot_types_PackageContextResolver$method$find$6acc62ea1c707b3c(_jc_env *, struct _jc_polyglot_types_PackageContextResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_types_PackageContextResolver$method$package__5f$2a2aa1010d61af28(_jc_env *, struct _jc_polyglot_types_PackageContextResolver$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_types_PackageContextResolver$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_types_PackageContextResolver$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_PackageContextResolver$method_info$find$6acc62ea1c707b3c;
extern _jc_method _jc_polyglot_types_PackageContextResolver$method_info$package__5f$2a2aa1010d61af28;
extern _jc_method _jc_polyglot_types_PackageContextResolver$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_types_PackageContextResolver$vmethods {
	struct _jc_object	*(*find$6acc62ea1c707b3c)(_jc_env *, struct _jc_polyglot_types_PackageContextResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*package__5f$2a2aa1010d61af28)(_jc_env *, struct _jc_polyglot_types_PackageContextResolver$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_types_PackageContextResolver$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_types_PackageContextResolver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_PackageContextResolver$vmethods	polyglot_types_PackageContextResolver;
};

// Vtype
struct _jc_polyglot_types_PackageContextResolver$vtype {
	_jc_type			type;
	_jc_polyglot_types_PackageContextResolver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_PackageContextResolver$sub_refs {
	struct _jc_object	*p;
	struct _jc_object	*ts;
	struct _jc_object	*cr;
};

// Reference instance fields (object)
struct _jc_polyglot_types_PackageContextResolver$refs {
    _jc_polyglot_types_PackageContextResolver$sub_refs	polyglot_types_PackageContextResolver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_PackageContextResolver$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_PackageContextResolver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_PackageContextResolver$sub_nonrefs	polyglot_types_PackageContextResolver;
};

// Object instance structure
struct _jc_polyglot_types_PackageContextResolver$object {
	_jc_polyglot_types_PackageContextResolver$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_PackageContextResolver$vtype	*vtype;
	_jc_polyglot_types_PackageContextResolver$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_PackageContextResolver$vtype _jc_polyglot_types_PackageContextResolver$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_PackageContextResolver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_PackageContextResolver$class_object;

#endif	/* _JC_polyglot_types_PackageContextResolver_H_ */
